package com.jeeplus.test.user.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.test.user.domain.SysUserInfo;
import com.jeeplus.test.user.service.dto.UserInfoDetailDto;
import com.jeeplus.test.user.service.UserInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@Slf4j
@Api(tags ="userInfo")
@RestController
@RequestMapping(value = "/sys/userInfo")
public class UserInfoController {

    @Resource
    private UserInfoService userInfoService;

    /**
     * 用户信息列表
     */
    @ApiOperation(value = "用户信息列表")
    @GetMapping(value = "/list")
    public ResponseEntity<IPage<SysUserInfo>> list(Page<SysUserInfo> page, SysUserInfo sysUserInfo) throws Exception{
        QueryWrapper<SysUserInfo> sysUserInfoQueryWrapper = QueryWrapperGenerator.buildQueryCondition(sysUserInfo, SysUserInfo.class);
        IPage<SysUserInfo> list = userInfoService.list(page, sysUserInfoQueryWrapper);
        return ResponseEntity.ok (list);
    }

    @ApiOperation(value = "删除用户信息")
    @GetMapping(value = "/remove")
    public String remove(@RequestParam String id) {
        return userInfoService.remove(id);
    }

    @ApiOperation(value = "根据id获取用户信息")
    @GetMapping(value = "/getUserInfoById")
    public UserInfoDetailDto getUserInfoById(@RequestParam String id) {
        return userInfoService.getUserInfoById(id);
    }

    @ApiOperation(value = "保存、更新数据")
    @PostMapping(value = "/save")
    public ResponseEntity save(@RequestBody UserInfoDetailDto userInfoDetailDto) {
        if (StringUtils.isEmpty(userInfoDetailDto.getId())) {
            return ResponseEntity.ok(userInfoService.add(userInfoDetailDto));
        }else {
            return ResponseEntity.ok(userInfoService.modify(userInfoDetailDto));
        }
    }
}
